@@ -71,7 +71,14 @@ class ScanCommand:
         self._controller = controller
         self.wavelengths = wavelegths
         self.positions = positions
-        self.results = {}
+        self.results = {'active_cavity': [],
+                        'x_set_point': [],
+                        'x': [],
+                        'y_set_point': [],
+                        'y': [],
+                        'wavelength_set_point': [],
+                        'wavelength': [],
+                        'detector_voltage': []}
         self.stopped = threading.Event()
         self.currentX = None
         self.currentY = None
@@ -130,6 +137,7 @@ class ScanCommand:
 
         except Exception as e:
             self.error = str(e)
+            logger.exception(e)
 
     def stop(self):
         self.stopped.set()
