@@ -16,7 +16,8 @@ if __name__ == '__main__':
 
     rsp.raise_for_status()
     print(rsp.json())
-    rsp = requests.post(url + '/scan/start')
+    rsp = requests.post(url + '/scan/start',
+                        json={'positions': [(1.0, 1.0), (3.0, 3.0)]})
     rsp.raise_for_status()
     rsp = requests.get(url + '/info')
 
